==> specutils_0.7.orig.tar.gz: specutils-0.7/specutils/__init__.py <==
# Licensed under a 3-clause BSD style license - see LICENSE.rst
"""
Specutils: an astropy package for spectroscopy.
"""

# Packages may add whatever they like to this file, but
# should keep this content at the top.
# ----------------------------------------------------------------------------
from ._astropy_init import *
from astropy import config as _config
# ----------------------------------------------------------------------------

# Enforce Python version check during package import.
# This is the same check as the one at the top of setup.py
import sys

__minimum_python_version__ = "3.5"


class UnsupportedPythonError(Exception):
    pass

if sys.version_info < tuple((int(val) for val in __minimum_python_version__.split('.'))):
    raise UnsupportedPythonError("packagename does not support Python < {}".format(__minimum_python_version__))

if not _ASTROPY_SETUP_:
    # For egg_info test builds to pass, put package imports here.

    # Allow loading spectrum object from top level module
    from .spectra import *

    # Load the IO functions
    from .io.default_loaders import *  # noqa
    from .io.registers import _load_user_io
    _load_user_io()

__citation__ = 'https://doi.org/10.5281/zenodo.1421356'

class Conf(_config.ConfigNamespace):
    """
    Configuration parameters for specutils.
    """

    do_continuum_function_check = _config.ConfigItem(
        True,
        'Whether to check the spectrum baseline value is close'
        'to zero. If it is not within ``threshold`` then a warning is raised.'
    )

conf = Conf()

==> specutils_1.6.0.orig.tar.gz: specutils-1.6.0/specutils/__init__.py <==
# Licensed under a 3-clause BSD style license - see LICENSE.rst
"""
Specutils: an astropy package for spectroscopy.
"""

# Packages may add whatever they like to this file, but
# should keep this content at the top.
# ----------------------------------------------------------------------------
from ._astropy_init import *   # noqa
from astropy import config as _config
# ----------------------------------------------------------------------------

# Enforce Python version check during package import.
# This is the same check as the one at the top of setup.py
import sys

__minimum_python_version__ = "3.5"


class UnsupportedPythonError(Exception):
    pass


if sys.version_info < tuple((int(val) for val in __minimum_python_version__.split('.'))):
    raise UnsupportedPythonError("packagename does not support Python < {}".format(__minimum_python_version__))

if not _ASTROPY_SETUP_:
    # For egg_info test builds to pass, put package imports here.

    # Allow loading spectrum object from top level module
    from .spectra import *

    # Load the IO functions
    from .io.default_loaders import *  # noqa
    from .io.registers import _load_user_io
    _load_user_io()

__citation__ = 'https://doi.org/10.5281/zenodo.1421356'


class Conf(_config.ConfigNamespace):
    """
    Configuration parameters for specutils.
    """

    do_continuum_function_check = _config.ConfigItem(
        True,
        'Whether to check the spectrum baseline value is close'
        'to zero. If it is not within ``threshold`` then a warning is raised.'
    )

conf = Conf()
